import sys

from gaphor.ui import main

if __name__ == "__main__":
    sys.exit(main(sys.argv))
